@@ -1,9 +1,13 @@
 from types import MethodType
 
+import django
 from django.core.exceptions import ObjectDoesNotExist
 from django.db import models
 from django.db.models.fields.files import FieldFile
-from django.utils.encoding import force_text
+if django.VERSION < (4, 0):
+    from django.utils.encoding import force_text as force_str
+else:
+    from django.utils.encoding import force_str
 from django.utils.functional import Promise
 from elasticsearch_dsl.field import (
     Boolean,
@@ -86,7 +90,7 @@ class DEDField(Field):
 
         # convert lazy object like lazy translations to string
         if isinstance(instance, Promise):
-            return force_text(instance)
+            return force_str(instance)
 
         return instance
 
